;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "tuareg" "20260626.936"
  "OCaml mode."
  '((emacs "26.3"))
  :url "https://github.com/ocaml/tuareg"
  :commit "2d67d53a66fbf9d83c0416dba3275080b1bc6dfd"
  :revdesc "2d67d53a66fb"
  :keywords '("ocaml" "languages")
  :authors '(("Albert Cohen" . "Albert.Cohen@inria.fr")
             ("Sam Steingold" . "sds@gnu.org")
             ("Christophe Troestler" . "Christophe.Troestler@umons.ac.be")
             ("Till Varoquaux" . "till@pps.jussieu.fr")
             ("Sean McLaughlin" . "seanmcl@gmail.com")
             ("Stefan Monnier" . "monnier@iro.umontreal.ca"))
  :maintainers '(("Christophe Troestler" . "Christophe.Troestler@umons.ac.be")
                 ("Stefan Monnier" . "monnier@iro.umontreal.ca")))
